@@ -13,9 +13,9 @@ def detect_text(path):
 
     response = client.text_detection(image=image)
     texts = response.text_annotations
-    print('Texts:')
 
-    print('{}'.format(texts[0].description))
+    print('\n"{}"'.format(texts[0].description))
+
 
     if response.error.message:
         raise Exception(
@@ -26,11 +26,8 @@ def detect_text(path):
 
 @click.command()
 @click.argument('filename')
-def detect(filename):
-    detect_text(filename)
-
-def main():
-    detect()
+def detect(fname):
+    detect_text(fname)
 
 if __name__ == '__main__':
-    main()
+    detect()
